Linear
------------------------

NNX linear layer classes.

.. automodule:: flax.nnx
.. currentmodule:: flax.nnx

.. autoclass:: Conv
   :members:
.. autoclass:: Embed
   :members:
.. autoclass:: Linear
   :members:
.. autoclass:: LinearGeneral
   :members:
.. autoclass:: Einsum
   :members:
